Installation — timeawarepc 2022 documentation

# Installation

Installation with `pip` is recommended. To use Granger Causality additional dependency of `nitime` is required. For detailed instructions, see below.

## Requirements

- Python >=3.6 and R >=4.0

- Install the R package requirements as follows in R.

    > install.packages("BiocManager")
    > BiocManager::install("graph")
    > BiocManager::install("RBGL")
    > install.packages("pcalg")
    > install.packages("kpcalg")

## Install `timeawarepc` using `pip`

    $ pip install timeawarepc

To install `timeawarepc` with `nitime` also:

    $ pip install nitime